Tutorial : using existing objects
=================================

.. include:: existing_objects/open_book.rst

.. include:: existing_objects/account.rst

.. include:: existing_objects/commodity.rst

.. include:: existing_objects/transaction.rst

.. include:: existing_objects/invoices.rst

.. include:: existing_objects/others.rst

.. include:: existing_objects/slots.rst

